@@ -73,6 +73,7 @@ WeekModel::WeekModel(QObject *parent)
 
 int WeekModel::rowCount(const QModelIndex &parent) const
 {
+    Q_UNUSED(parent);
     return 7;
 }
 
@@ -93,3 +94,5 @@ QHash<int, QByteArray> WeekModel::roleNames() const
 {
     return {{NameRole, "name"}, {FlagRole, "flag"}};
 }
+
+#include "moc_kclockformat.cpp"
